# triodos-fund-analyzer

This is a small tool to visualize the value of Triodos funds.

## Ethics

Holding shares usually is not ethical for a number of reasons. Triodos
funds are among the rare exceptions that have less unethical impact.

In general it is not ethical to make profits of other peoples work. Even
more so, because for the largest part the unequal distribution of wealth
requires the poor to borrow money for their causes.

It may be ethical if you give the profits of fund investments to
[objectively](https://www.britannica.com/topic/effective-altruism)
[good](https://plato.stanford.edu/entries/common-good/) projects.

## The tool

If you (plan to) own shares of funds, you may want to know how they do.
If that concerns Triodos funds, you can use this tool to visualize the
course history, including optional corrections.

### Check it out

Check it out online https://triodos-fund-analyzer.streamlit.app/

### Install it

`pip install triodos_fund_analyzer`

### Use it

For now, run `plot-funds <Triodos ... Fund>` from a shell. If you know
your stuff, feel free to use the implemented function to build a plot to
you liking - you're welcome to feed it back via Pull Requests.

-----
**That's it, have fun!**
